/*
 * Contains definitions for the packet driver for the RTK8019as 10megabit
 * ethernet controller chip.
 *
 * (C) 2001 Softools, Inc.
 * (C) 2001 Compendium Technologies, Inc.
 * All rights reserved.
 *
 * Translated from the Z-World packet driver and used under license.
 */

#ifndef _RTK8019AS_H_
#define _RTK8019AS_H_

#include "lwip/netif.h"
#include "netif/arp.h"

#define PD_COMMAND      0xc000
#define PD_RD           0xe000
#define PD_PAGESTART    1
#define PD_PAGESTOP     2
#define PD_BOUNDARY     3
#define PD_TXSTATUS	    4
#define PD_TXPAGE       4
#define PD_TXBCNT0      5
#define PD_NCR          5
#define PD_TXBCNT1      6
#define PD_INTSTATUS    7
#define PD_CURRENT      7
#define PD_RMTSADR0     8
#define PD_CRDMA0       8
#define PD_RMTSADR1     9
#define PD_CRDMA1       9
#define PD_RMTBCNT0     0xa
#define PD_RMTBCNT1     0xb
#define PD_RXSTATUS     0xc
#define PD_RXCFG        0xc
#define PD_TXCFG        0xd
#define PD_DATACFG      0xe
#define PD_INTMASK      0xf
#define PD_IOPORT       16
#define PD_RESET        0x1f
#define PD_9346CR       0x01
#define PD_CONFIG2	0x05
#define PD_CONFIG3	0x06

#define PD_PAGE_STOP	0x60

/*
 * Low-level interface routines
 */

void RealTekInit(struct netif * interface);
int  RealTekSendPacket(struct pbuf * sendChain);
struct pbuf * RealTekRecvPacket(void);

/**
 * Initialization function for the driver
 */
void _nearcall RTK8019AS_if_init(struct netif *netif);
u16_t RTK8019AS_if_input(struct netif *netif);

extern unsigned int  rtkReadAddress;  // Allows configuration of the read
                                      // address for the packet driver
extern unsigned int  rtkWriteAddress; // Allows configuration of the write
                                      // address for the packet driver
extern unsigned char rtkLEDs;         // Bitmask to light the ethernet LEDs
extern unsigned int  rtkEEPORT;       // What port to use for the EEPROM
                                      // emulation routines (clock)
extern unsigned int  rtkEEDO;         // What register to use for writing from
                                      // the emulated EEPROM to the 8019as
extern unsigned char rtkEEDI;         // What register to use for reading from
                                      // the 8019as as the emulated EEPROM
extern unsigned char rtkEESK;         // What register to use for reading the
                                      // EEPROM clock pulse from the 8019as

#define RTK_BOARD_TYPE_DEVKIT  0
#define RTK_BOARD_TYPE_RCM2100 1
#define RTK_BOARD_TYPE_RCM2200 2
#define RTK_BOARD_TYPE_RCM3000 3

extern unsigned char rtkBoardType;    // Board or core module in use

// Ethernet (MAC) address for core modules
extern struct eth_addr rtkEthernetAddress;

/*
 * Structure specific to this type of network interface. Right now contains
 * just the ethernet address.
 */
struct ethernetif {
    struct eth_addr *ethaddr;
    /* Add whatever per-interface state that is needed here. */
};

#endif /* _RTK8019AS_H_ */
